Expect results, not exceptions!
-------------------------------

.. image:: https://img.shields.io/badge/python-3.8-blue.svg

Under development.


Bugs/Requests
-------------

Please use the `GitHub issue tracker`_ to submit bugs or request features.

.. _`GitHub issue tracker`: https://github.com/kprzybyla/resultful/issues


License
-------

Copyright Krzysztof Przybyła, 2020.

Distributed under the terms of the `MIT`_ license.

.. _`MIT`: https://github.com/kprzybyla/resultful/blob/master/LICENSE
